Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-11-18 22:14:20 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-11-18 22:27:17 +0300
commit074cd53c19311955031f88d2486ac475ba43f806 (patch)
treed83f1daaeb4e7a6aa6a6218a5d3009a6338ebaf6 /source/blender/makesdna/DNA_windowmanager_types.h
parent64920a8febde6df596fe7c8e62c570db2f29ab95 (diff)
Keymap: move left click select to a preference
Diffstat (limited to 'source/blender/makesdna/DNA_windowmanager_types.h')
-rw-r--r--source/blender/makesdna/DNA_windowmanager_types.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/source/blender/makesdna/DNA_windowmanager_types.h b/source/blender/makesdna/DNA_windowmanager_types.h
index 88974750ffb..193c34e3d11 100644
--- a/source/blender/makesdna/DNA_windowmanager_types.h
+++ b/source/blender/makesdna/DNA_windowmanager_types.h
@@ -352,14 +352,14 @@ enum {
* This is similar to addon-preferences,
* however unlike add-ons key-config's aren't saved to disk.
*
* #wmKeyConfigPrefType is written to DNA,
* #wmKeyConfigPrefType_Runtime has the RNA type.
*/
-typedef struct wmKeyConfigPrefType {
- struct wmKeyConfigPrefType *next, *prev;
+typedef struct wmKeyConfigPref {
+ struct wmKeyConfigPref *next, *prev;
char idname[64]; /* unique name */
IDProperty *prop;
-} wmKeyConfigPrefType;
+} wmKeyConfigPref;
typedef struct wmKeyConfig {
struct wmKeyConfig *next, *prev;
@@ -370,10 +370,7 @@ typedef struct wmKeyConfig {
ListBase keymaps;
int actkeymap;
short flag;
-
- /* Supports select mouse switching? */
- char has_select_mouse; /* may remove in favor of custom properties. */
- char _pad0;
+ char _pad0[2];
} wmKeyConfig;
/* wmKeyConfig.flag */
@@ -352,14 +352,14 @@ enum {
* however unlike add-ons key-config's aren't saved to disk.
*
- * #wmKeyConfigPrefType is written to DNA,
+ * #wmKeyConfigPref is written to DNA,
* #wmKeyConfigPrefType_Runtime has the RNA type.
*/